@@ -282,7 +282,7 @@ class Desktop(MethodsInterface):
 
     def terminateUserSession(self, session_id):
         loginctl = getProgPath("/bin/loginctl")
-        p = process(loginctl, "--terminate-session", session_id)
+        p = process(loginctl, "terminate-session", session_id)
         return p.success()
 
     def userLogoutByElogind(self, urLogin):
